==> servicediscovery-1.60.0-sources.jar: software/amazon/awscdk/services/servicediscovery/CnameInstanceProps.java <==
package software.amazon.awscdk.services.servicediscovery;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:23.791Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicediscovery.$Module.class, fqn = "@aws-cdk/aws-servicediscovery.CnameInstanceProps")
@software.amazon.jsii.Jsii.Proxy(CnameInstanceProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CnameInstanceProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.servicediscovery.CnameInstanceBaseProps {

    /**
     * The Cloudmap service this resource is registered to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicediscovery.IService getService();

    /**
     * @return a {@link Builder} of {@link CnameInstanceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CnameInstanceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CnameInstanceProps> {
        private software.amazon.awscdk.services.servicediscovery.IService service;
        private java.lang.String instanceCname;
        private java.util.Map<java.lang.String, java.lang.String> customAttributes;
        private java.lang.String instanceId;

        /**
         * Sets the value of {@link CnameInstanceProps#getService}
         * @param service The Cloudmap service this resource is registered to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder service(software.amazon.awscdk.services.servicediscovery.IService service) {
            this.service = service;
            return this;
        }

        /**
         * Sets the value of {@link CnameInstanceProps#getInstanceCname}
         * @param instanceCname If the service configuration includes a CNAME record, the domain name that you want Route 53 to return in response to DNS queries, for example, example.com. This value is required if the service specified by ServiceId includes settings for an CNAME record. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder instanceCname(java.lang.String instanceCname) {
            this.instanceCname = instanceCname;
            return this;
        }

        /**
         * Sets the value of {@link CnameInstanceProps#getCustomAttributes}
         * @param customAttributes Custom attributes of the instance.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customAttributes(java.util.Map<java.lang.String, java.lang.String> customAttributes) {
            this.customAttributes = customAttributes;
            return this;
        }

        /**
         * Sets the value of {@link CnameInstanceProps#getInstanceId}
         * @param instanceId The id of the instance resource.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder instanceId(java.lang.String instanceId) {
            this.instanceId = instanceId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CnameInstanceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CnameInstanceProps build() {
            return new Jsii$Proxy(service, instanceCname, customAttributes, instanceId);
        }
    }

    /**
     * An implementation for {@link CnameInstanceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CnameInstanceProps {
        private final software.amazon.awscdk.services.servicediscovery.IService service;
        private final java.lang.String instanceCname;
        private final java.util.Map<java.lang.String, java.lang.String> customAttributes;
        private final java.lang.String instanceId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.service = this.jsiiGet("service", software.amazon.awscdk.services.servicediscovery.IService.class);
            this.instanceCname = this.jsiiGet("instanceCname", java.lang.String.class);
            this.customAttributes = this.jsiiGet("customAttributes", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.instanceId = this.jsiiGet("instanceId", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.servicediscovery.IService service, final java.lang.String instanceCname, final java.util.Map<java.lang.String, java.lang.String> customAttributes, final java.lang.String instanceId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.service = java.util.Objects.requireNonNull(service, "service is required");
            this.instanceCname = java.util.Objects.requireNonNull(instanceCname, "instanceCname is required");
            this.customAttributes = customAttributes;
            this.instanceId = instanceId;
        }

        @Override
        public software.amazon.awscdk.services.servicediscovery.IService getService() {
            return this.service;
        }

        @Override
        public java.lang.String getInstanceCname() {
            return this.instanceCname;
        }

        @Override
        public java.util.Map<java.lang.String, java.lang.String> getCustomAttributes() {
            return this.customAttributes;
        }

        @Override
        public java.lang.String getInstanceId() {
            return this.instanceId;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("service", om.valueToTree(this.getService()));
            data.set("instanceCname", om.valueToTree(this.getInstanceCname()));
            if (this.getCustomAttributes() != null) {
                data.set("customAttributes", om.valueToTree(this.getCustomAttributes()));
            }
            if (this.getInstanceId() != null) {
                data.set("instanceId", om.valueToTree(this.getInstanceId()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-servicediscovery.CnameInstanceProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CnameInstanceProps.Jsii$Proxy that = (CnameInstanceProps.Jsii$Proxy) o;

            if (!service.equals(that.service)) return false;
            if (!instanceCname.equals(that.instanceCname)) return false;
            if (this.customAttributes != null ? !this.customAttributes.equals(that.customAttributes) : that.customAttributes != null) return false;
            return this.instanceId != null ? this.instanceId.equals(that.instanceId) : that.instanceId == null;
        }

        @Override
        public int hashCode() {
            int result = this.service.hashCode();
            result = 31 * result + (this.instanceCname.hashCode());
            result = 31 * result + (this.customAttributes != null ? this.customAttributes.hashCode() : 0);
            result = 31 * result + (this.instanceId != null ? this.instanceId.hashCode() : 0);
            return result;
        }
    }
}

==> servicediscovery-1.101.0-sources.jar: software/amazon/awscdk/services/servicediscovery/CnameInstanceProps.java <==
package software.amazon.awscdk.services.servicediscovery;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:08:05.588Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicediscovery.$Module.class, fqn = "@aws-cdk/aws-servicediscovery.CnameInstanceProps")
@software.amazon.jsii.Jsii.Proxy(CnameInstanceProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CnameInstanceProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.servicediscovery.CnameInstanceBaseProps {

    /**
     * The Cloudmap service this resource is registered to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicediscovery.IService getService();

    /**
     * @return a {@link Builder} of {@link CnameInstanceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CnameInstanceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CnameInstanceProps> {
        private software.amazon.awscdk.services.servicediscovery.IService service;
        private java.lang.String instanceCname;
        private java.util.Map<java.lang.String, java.lang.String> customAttributes;
        private java.lang.String instanceId;

        /**
         * Sets the value of {@link CnameInstanceProps#getService}
         * @param service The Cloudmap service this resource is registered to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder service(software.amazon.awscdk.services.servicediscovery.IService service) {
            this.service = service;
            return this;
        }

        /**
         * Sets the value of {@link CnameInstanceProps#getInstanceCname}
         * @param instanceCname If the service configuration includes a CNAME record, the domain name that you want Route 53 to return in response to DNS queries, for example, example.com. This value is required if the service specified by ServiceId includes settings for an CNAME record. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder instanceCname(java.lang.String instanceCname) {
            this.instanceCname = instanceCname;
            return this;
        }

        /**
         * Sets the value of {@link CnameInstanceProps#getCustomAttributes}
         * @param customAttributes Custom attributes of the instance.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customAttributes(java.util.Map<java.lang.String, java.lang.String> customAttributes) {
            this.customAttributes = customAttributes;
            return this;
        }

        /**
         * Sets the value of {@link CnameInstanceProps#getInstanceId}
         * @param instanceId The id of the instance resource.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder instanceId(java.lang.String instanceId) {
            this.instanceId = instanceId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CnameInstanceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CnameInstanceProps build() {
            return new Jsii$Proxy(service, instanceCname, customAttributes, instanceId);
        }
    }

    /**
     * An implementation for {@link CnameInstanceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CnameInstanceProps {
        private final software.amazon.awscdk.services.servicediscovery.IService service;
        private final java.lang.String instanceCname;
        private final java.util.Map<java.lang.String, java.lang.String> customAttributes;
        private final java.lang.String instanceId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.service = software.amazon.jsii.Kernel.get(this, "service", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.servicediscovery.IService.class));
            this.instanceCname = software.amazon.jsii.Kernel.get(this, "instanceCname", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.customAttributes = software.amazon.jsii.Kernel.get(this, "customAttributes", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.instanceId = software.amazon.jsii.Kernel.get(this, "instanceId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.servicediscovery.IService service, final java.lang.String instanceCname, final java.util.Map<java.lang.String, java.lang.String> customAttributes, final java.lang.String instanceId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.service = java.util.Objects.requireNonNull(service, "service is required");
            this.instanceCname = java.util.Objects.requireNonNull(instanceCname, "instanceCname is required");
            this.customAttributes = customAttributes;
            this.instanceId = instanceId;
        }

        @Override
        public final software.amazon.awscdk.services.servicediscovery.IService getService() {
            return this.service;
        }

        @Override
        public final java.lang.String getInstanceCname() {
            return this.instanceCname;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getCustomAttributes() {
            return this.customAttributes;
        }

        @Override
        public final java.lang.String getInstanceId() {
            return this.instanceId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("service", om.valueToTree(this.getService()));
            data.set("instanceCname", om.valueToTree(this.getInstanceCname()));
            if (this.getCustomAttributes() != null) {
                data.set("customAttributes", om.valueToTree(this.getCustomAttributes()));
            }
            if (this.getInstanceId() != null) {
                data.set("instanceId", om.valueToTree(this.getInstanceId()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-servicediscovery.CnameInstanceProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CnameInstanceProps.Jsii$Proxy that = (CnameInstanceProps.Jsii$Proxy) o;

            if (!service.equals(that.service)) return false;
            if (!instanceCname.equals(that.instanceCname)) return false;
            if (this.customAttributes != null ? !this.customAttributes.equals(that.customAttributes) : that.customAttributes != null) return false;
            return this.instanceId != null ? this.instanceId.equals(that.instanceId) : that.instanceId == null;
        }

        @Override
        public final int hashCode() {
            int result = this.service.hashCode();
            result = 31 * result + (this.instanceCname.hashCode());
            result = 31 * result + (this.customAttributes != null ? this.customAttributes.hashCode() : 0);
            result = 31 * result + (this.instanceId != null ? this.instanceId.hashCode() : 0);
            return result;
        }
    }
}
